==> qucs-s-debug-24.4.0-1-x86_64.pkg.tar.zst: usr/src/debug/qucs-s/qucs-s-24.4.0/builddir/qucsator_rf/src/parse_netlist.hpp <==
/* A Bison parser, made by GNU Bison 3.8.2.  */

/* Bison interface for Yacc-like parsers in C

   Copyright (C) 1984, 1989-1990, 2000-2015, 2018-2021 Free Software Foundation,
   Inc.

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <https://www.gnu.org/licenses/>.  */

/* As a special exception, you may create a larger work that contains
   part or all of the Bison parser skeleton and distribute that work
   under terms of your choice, so long as that work isn't itself a
   parser generator using the skeleton or a modified version thereof
   as a parser skeleton.  Alternatively, if you modify or redistribute
   the parser skeleton itself, you may (at your option) remove this
   special exception, which will cause the skeleton and the resulting
   Bison output files to be licensed under the GNU General Public
   License without this special exception.

   This special exception was added by the Free Software Foundation in
   version 2.2 of Bison.  */

/* DO NOT RELY ON FEATURES THAT ARE NOT DOCUMENTED in the manual,
   especially those whose name start with YY_ or yy_.  They are
   private implementation details that can be changed or removed.  */

#ifndef YY_NETLIST_PARSE_NETLIST_HPP_INCLUDED
# define YY_NETLIST_PARSE_NETLIST_HPP_INCLUDED
/* Debug traces.  */
#ifndef YYDEBUG
# define YYDEBUG 0
#endif
#if YYDEBUG
extern int netlist_debug;
#endif

/* Token kinds.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
  enum yytokentype
  {
    YYEMPTY = -2,
    YYEOF = 0,                     /* "end of file"  */
    YYerror = 256,                 /* error  */
    YYUNDEF = 257,                 /* "invalid token"  */
    InvalidCharacter = 258,        /* InvalidCharacter  */
    Identifier = 259,              /* Identifier  */
    Assign = 260,                  /* Assign  */
    ScaleOrUnit = 261,             /* ScaleOrUnit  */
    Eol = 262,                     /* Eol  */
    Eqn = 263,                     /* Eqn  */
    DefSub = 264,                  /* DefSub  */
    EndSub = 265,                  /* EndSub  */
    REAL = 266,                    /* REAL  */
    IMAG = 267,                    /* IMAG  */
    COMPLEX = 268,                 /* COMPLEX  */
    Character = 269,               /* Character  */
    STRING = 270,                  /* STRING  */
    Or = 271,                      /* Or  */
    And = 272,                     /* And  */
    NotEqual = 273,                /* NotEqual  */
    Equal = 274,                   /* Equal  */
    Less = 275,                    /* Less  */
    Greater = 276,                 /* Greater  */
    LessOrEqual = 277,             /* LessOrEqual  */
    GreaterOrEqual = 278,          /* GreaterOrEqual  */
    Not = 279,                     /* Not  */
    NEG = 280,                     /* NEG  */
    POS = 281                      /* POS  */
  };
  typedef enum yytokentype yytoken_kind_t;
#endif

/* Value type.  */
#if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
union YYSTYPE
{
#line 78 "/build/qucs-s/src/qucs-s-24.4.0/qucsator_rf/src/parse_netlist.ypp"

  char * ident;
  char * str;
  double d;
  char chr;
  struct definition_t * definition;
  struct definition_t * subcircuit;
  struct node_t * node;
  struct pair_t * pair;
  struct value_t * value;
  struct {
    double r;
    double i;
  } c;
  qucs::eqn::node * eqn;
  qucs::eqn::constant * con;
  qucs::eqn::reference * ref;
  qucs::eqn::application * app;
  qucs::eqn::assignment * assign;

#line 111 "parse_netlist.hpp"

};
typedef union YYSTYPE YYSTYPE;
# define YYSTYPE_IS_TRIVIAL 1
# define YYSTYPE_IS_DECLARED 1
#endif


extern YYSTYPE netlist_lval;


int netlist_parse (void);


#endif /* !YY_NETLIST_PARSE_NETLIST_HPP_INCLUDED  */

==> qucs-s-debug-25.1.1-1-x86_64.pkg.tar.zst: usr/src/debug/qucs-s/qucs-s-25.1.1/builddir/qucsator_rf/src/parse_netlist.hpp <==
/* A Bison parser, made by GNU Bison 3.8.2.  */

/* Bison interface for Yacc-like parsers in C

   Copyright (C) 1984, 1989-1990, 2000-2015, 2018-2021 Free Software Foundation,
   Inc.

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <https://www.gnu.org/licenses/>.  */

/* As a special exception, you may create a larger work that contains
   part or all of the Bison parser skeleton and distribute that work
   under terms of your choice, so long as that work isn't itself a
   parser generator using the skeleton or a modified version thereof
   as a parser skeleton.  Alternatively, if you modify or redistribute
   the parser skeleton itself, you may (at your option) remove this
   special exception, which will cause the skeleton and the resulting
   Bison output files to be licensed under the GNU General Public
   License without this special exception.

   This special exception was added by the Free Software Foundation in
   version 2.2 of Bison.  */

/* DO NOT RELY ON FEATURES THAT ARE NOT DOCUMENTED in the manual,
   especially those whose name start with YY_ or yy_.  They are
   private implementation details that can be changed or removed.  */

#ifndef YY_NETLIST_PARSE_NETLIST_HPP_INCLUDED
# define YY_NETLIST_PARSE_NETLIST_HPP_INCLUDED
/* Debug traces.  */
#ifndef NETLIST_DEBUG
# if defined YYDEBUG
#if YYDEBUG
#   define NETLIST_DEBUG 1
#  else
#   define NETLIST_DEBUG 0
#  endif
# else /* ! defined YYDEBUG */
#  define NETLIST_DEBUG 0
# endif /* ! defined YYDEBUG */
#endif  /* ! defined NETLIST_DEBUG */
#if NETLIST_DEBUG
extern int netlist_debug;
#endif

/* Token kinds.  */
#ifndef NETLIST_TOKENTYPE
# define NETLIST_TOKENTYPE
  enum netlist_tokentype
  {
    NETLIST_EMPTY = -2,
    NETLIST_EOF = 0,               /* "end of file"  */
    NETLIST_error = 256,           /* error  */
    NETLIST_UNDEF = 257,           /* "invalid token"  */
    InvalidCharacter = 258,        /* InvalidCharacter  */
    Identifier = 259,              /* Identifier  */
    Assign = 260,                  /* Assign  */
    ScaleOrUnit = 261,             /* ScaleOrUnit  */
    Eol = 262,                     /* Eol  */
    Eqn = 263,                     /* Eqn  */
    DefSub = 264,                  /* DefSub  */
    EndSub = 265,                  /* EndSub  */
    REAL = 266,                    /* REAL  */
    IMAG = 267,                    /* IMAG  */
    COMPLEX = 268,                 /* COMPLEX  */
    Character = 269,               /* Character  */
    STRING = 270,                  /* STRING  */
    Or = 271,                      /* Or  */
    And = 272,                     /* And  */
    NotEqual = 273,                /* NotEqual  */
    Equal = 274,                   /* Equal  */
    Less = 275,                    /* Less  */
    Greater = 276,                 /* Greater  */
    LessOrEqual = 277,             /* LessOrEqual  */
    GreaterOrEqual = 278,          /* GreaterOrEqual  */
    Not = 279,                     /* Not  */
    NEG = 280,                     /* NEG  */
    POS = 281                      /* POS  */
  };
  typedef enum netlist_tokentype netlist_token_kind_t;
#endif

/* Value type.  */
#if ! defined NETLIST_STYPE && ! defined NETLIST_STYPE_IS_DECLARED
union NETLIST_STYPE
{
#line 78 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/parse_netlist.ypp"

  char * ident;
  char * str;
  double d;
  char chr;
  struct definition_t * definition;
  struct definition_t * subcircuit;
  struct node_t * node;
  struct pair_t * pair;
  struct value_t * value;
  struct {
    double r;
    double i;
  } c;
  qucs::eqn::node * eqn;
  qucs::eqn::constant * con;
  qucs::eqn::reference * ref;
  qucs::eqn::application * app;
  qucs::eqn::assignment * assign;

#line 119 "parse_netlist.hpp"

};
typedef union NETLIST_STYPE NETLIST_STYPE;
# define NETLIST_STYPE_IS_TRIVIAL 1
# define NETLIST_STYPE_IS_DECLARED 1
#endif


extern NETLIST_STYPE netlist_lval;


int netlist_parse (void);


#endif /* !YY_NETLIST_PARSE_NETLIST_HPP_INCLUDED  */
